==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/files_reminders/l10n/ar.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "التذكير بالملفات",
    "Reminder for {name}" : "تذكير لـ {name}",
    "View file" : "أعرُض الملف",
    "View folder" : "أعرُض المجلد",
    "Set file reminders" : "ضبط تذكير بالملفات",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 التذكير بالملفات** \n\nضبط التذكير بالملفات. \n\nملاحظة: لاستخدام تطبيق \"التذكير بالملفات\"، تأكد من تثبيت تطبيق الإشعارات وتمكينه. يوفر تطبيق الإشعارات واجهة برمجة التطبيقات API اللازمة لتطبيق \"التذكير بالملفات\" ليعمل بالشكل الصحيح.",
    "Set reminder for \"{fileName}\"" : "ضبط تذكير بالملف \"{fileName}\"",
    "Set reminder at custom date & time" : "حدّد التذكير في وقت و تاريخ مخصص",
    "Clear reminder" : "محو التذكير",
    "Please choose a valid date & time" : "من فضلك، إختَر وقتاً و تاريخاً صحيحين",
    "Reminder set for \"{fileName}\"" : "تمّ ضبط تذكير بالملف \"{fileName}\"",
    "Failed to set reminder" : "تعذّر ضبط التذكير",
    "Reminder cleared for \"{fileName}\"" : "تمّ إلغاء التذكير بالملف \"{fileName}\"",
    "Failed to clear reminder" : "تعذّرت إزالة التذكير",
    "We will remind you of this file" : "سوف يتم تذكيرك بهذا الملف",
    "Cancel" : "إلغاء",
    "Set reminder" : "ضبط التذكير",
    "Reminder set" : "تمّ وضع تذكير",
    "Set custom reminder" : "ضبط تذكير مخصص",
    "Later today" : "في وقت لاحقٍ اليوم",
    "Set reminder for later today" : "إضبِط التذكير لوقت لاحقٍ اليوم",
    "Tomorrow" : "غداً",
    "Set reminder for tomorrow" : "إضبِط التذكير للغد",
    "This weekend" : "نهاية هذا الأسبوع",
    "Set reminder for this weekend" : "إضبِط التذكير لنهاية هذا الأسبوع",
    "Next week" : "الأسبوع القادم",
    "Set reminder for next week" : "إضبِط التذكير للأسبوع القادم"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-29.0.15.tar.bz2: nextcloud/apps/files_reminders/l10n/ar.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "التذكير بالملفات",
    "Reminder for {name}" : "تذكير لـ {name}",
    "View file" : "أعرُض الملف",
    "View folder" : "أعرُض المجلد",
    "Files reminder" : "التذكير بالملفات",
    "This files_reminder can work properly." : "وظيفة التذكير بالملفات هذه تعمل بالشكل الصحيح.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "تطبيق التذكير بالملفات يحتاج إلى تطبيق الإشعارات ليعمل بالشكل الصحيح. عليك إمّا أن تقوم بتمكين الإشعارات او تعطيل التذكير بالملفات.",
    "Set file reminders" : "ضبط تذكير بالملفات",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 التذكير بالملفات** \n\nضبط التذكير بالملفات. \n\nملاحظة: لاستخدام تطبيق \"التذكير بالملفات\"، تأكد من تثبيت تطبيق الإشعارات وتمكينه. يوفر تطبيق الإشعارات واجهة برمجة التطبيقات API اللازمة لتطبيق \"التذكير بالملفات\" ليعمل بالشكل الصحيح.",
    "Set reminder for \"{fileName}\"" : "ضبط تذكير بالملف \"{fileName}\"",
    "Set reminder at custom date & time" : "حدّد التذكير في وقت و تاريخ مخصص",
    "Clear reminder" : "محو التذكير",
    "Please choose a valid date & time" : "من فضلك، إختَر وقتاً و تاريخاً صحيحين",
    "Reminder set for \"{fileName}\"" : "تمّ ضبط تذكير بالملف \"{fileName}\"",
    "Failed to set reminder" : "تعذّر ضبط التذكير",
    "Reminder cleared for \"{fileName}\"" : "تمّ إلغاء التذكير بالملف \"{fileName}\"",
    "Failed to clear reminder" : "تعذّرت إزالة التذكير",
    "We will remind you of this file" : "سوف يتم تذكيرك بهذا الملف",
    "Cancel" : "إلغاء",
    "Set reminder" : "ضبط التذكير",
    "Reminder set" : "تمّ وضع تذكير",
    "Set custom reminder" : "ضبط تذكير مخصص",
    "Later today" : "في وقت لاحقٍ اليوم",
    "Set reminder for later today" : "إضبِط التذكير لوقت لاحقٍ اليوم",
    "Tomorrow" : "غداً",
    "Set reminder for tomorrow" : "إضبِط التذكير للغد",
    "This weekend" : "نهاية هذا الأسبوع",
    "Set reminder for this weekend" : "إضبِط التذكير لنهاية هذا الأسبوع",
    "Next week" : "الأسبوع القادم",
    "Set reminder for next week" : "إضبِط التذكير للأسبوع القادم"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
